----------------------------------------------------------------------------------
-- Company: CAL POLY SLO
-- Engineer: Mairead Blaes and Edwin Wong
-- 
-- Create Date:    14:00:49 12/04/2014 
-- Design Name: 
-- Module Name:    Whole_Game - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: The top module that ties together all the modules to complete the game.
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity Whole_Game is
    Port ( clk : in  STD_LOGIC;
           switches : in  STD_LOGIC_VECTOR (7 downto 0);--player input
           en : in  STD_LOGIC;--button on Nexys 2 board
           reset_btn : in  STD_LOGIC;--button on Nexys 2 board
           row : out  STD_LOGIC_VECTOR (7 downto 0);--rows of LED matrix
			  column : out  STD_LOGIC_VECTOR (7 downto 0);--columns of LED matrix
           segments : out  STD_LOGIC_VECTOR (7 downto 0);--for seven-segement display
           anodes : out  STD_LOGIC_VECTOR (3 downto 0);--for seven-segement display
			  LEDs : out  STD_LOGIC_VECTOR (3 downto 0));--LED's on Nexys 2 board
end Whole_Game;

architecture Behavioral of Whole_Game is

----------------------------------------------------------------------------------
--bringing in all the modules
----------------------------------------------------------------------------------
component Linear_FB_Register is
    Port ( lfsr8_out : out  STD_LOGIC_VECTOR(7 downto 0);
           clk : in  STD_LOGIC;
           reset : in  STD_LOGIC);
end component;

component COMP8 is
    Port ( SWITCHES : in  STD_LOGIC_VECTOR (7 downto 0);
           SSEG : in  STD_LOGIC_VECTOR (7 downto 0);
           EQ : out  STD_LOGIC;
           LT : out  STD_LOGIC;
           GT : out  STD_LOGIC);
end component;

component Game_State is
    Port ( equal : in  STD_LOGIC;
           less : in  STD_LOGIC;
           greater : in  STD_LOGIC;
			  CLR: in STD_LOGIC;
			  CLK: in STD_LOGIC;
			  game_output: out STD_LOGIC);
end component;

component Display_Game_Outcome is
    Port ( row : out  STD_LOGIC_VECTOR (7 downto 0);
           column : out  STD_LOGIC_VECTOR (7 downto 0);
			  LEDs: out STD_LOGIC_VECTOR(3 downto 0);
           game_output : in  STD_LOGIC);
end component;

component Random_Num_display is
    Port ( clk : in  STD_LOGIC;
           en, reset_btn : in  STD_LOGIC;
           segments : out  STD_LOGIC_VECTOR (7 downto 0);
           anodes : out  STD_LOGIC_VECTOR (3 downto 0);
			  D_num_out: inout STD_LOGIC_VECTOR (7 downto 0));
end component;

signal random_number: std_logic_vector(7 downto 0);--number that is latched from the random number generator 
signal equal, less, greater: std_logic;--difference between player input and given number
signal state: std_logic;--which state the game is in

----------------------------------------------------------------------------------
--tying the modules together
----------------------------------------------------------------------------------
begin
	
Comparator: COMP8 port map(
	SWITCHES => switches,
	SSEG => random_number,
	EQ => equal,
	LT => less,
	GT => greater);
	
Game_State_Controller: Game_State port map(
	equal => equal,
	less => less,
	greater => greater,
	CLR => reset_btn,
	CLK => clk,
	game_output => state);
	
LED_Matrix_Display: Display_Game_Outcome port map(
	row => row,
	column => column,
	LEDs => LEDs,
	game_output => state);

Random_Number_Display: Random_Num_display port map(
	clk => clk,
	en => en,
	reset_btn => reset_btn,
	segments => segments,
	anodes => anodes,
	D_num_out => random_number);

end Behavioral;

